pub enum IValidatorConfigV2Calls {
Show 19 variants
getActiveValidators(getActiveValidatorsCall),
getInitializedAtHeight(getInitializedAtHeightCall),
owner(ownerCall),
validatorCount(validatorCountCall),
validatorByIndex(validatorByIndexCall),
validatorByAddress(validatorByAddressCall),
validatorByPublicKey(validatorByPublicKeyCall),
getNextNetworkIdentityRotationEpoch(getNextNetworkIdentityRotationEpochCall),
isInitialized(isInitializedCall),
addValidator(addValidatorCall),
deactivateValidator(deactivateValidatorCall),
rotateValidator(rotateValidatorCall),
setFeeRecipient(setFeeRecipientCall),
setIpAddresses(setIpAddressesCall),
transferValidatorOwnership(transferValidatorOwnershipCall),
transferOwnership(transferOwnershipCall),
setNetworkIdentityRotationEpoch(setNetworkIdentityRotationEpochCall),
migrateValidator(migrateValidatorCall),
initializeIfMigrated(initializeIfMigratedCall),
}Expand description
Container for all the IValidatorConfigV2 function calls.
Variants
getActiveValidators(getActiveValidatorsCall)
getInitializedAtHeight(getInitializedAtHeightCall)
owner(ownerCall)
validatorCount(validatorCountCall)
validatorByIndex(validatorByIndexCall)
validatorByAddress(validatorByAddressCall)
validatorByPublicKey(validatorByPublicKeyCall)
getNextNetworkIdentityRotationEpoch(getNextNetworkIdentityRotationEpochCall)
isInitialized(isInitializedCall)
addValidator(addValidatorCall)
deactivateValidator(deactivateValidatorCall)
rotateValidator(rotateValidatorCall)
setFeeRecipient(setFeeRecipientCall)
setIpAddresses(setIpAddressesCall)
transferValidatorOwnership(transferValidatorOwnershipCall)
transferOwnership(transferOwnershipCall)
setNetworkIdentityRotationEpoch(setNetworkIdentityRotationEpochCall)
migrateValidator(migrateValidatorCall)
initializeIfMigrated(initializeIfMigratedCall)
Implementations
Sourceimpl IValidatorConfigV2Calls
impl IValidatorConfigV2Calls
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.