pub enum IValidatorConfigV2Errors {
Show 18 variants
AlreadyInitialized(AlreadyInitialized),
IngressAlreadyExists(IngressAlreadyExists),
EmptyV1ValidatorSet(EmptyV1ValidatorSet),
InvalidMigrationIndex(InvalidMigrationIndex),
InvalidOwner(InvalidOwner),
InvalidPublicKey(InvalidPublicKey),
InvalidSignature(InvalidSignature),
InvalidSignatureFormat(InvalidSignatureFormat),
InvalidValidatorAddress(InvalidValidatorAddress),
MigrationNotComplete(MigrationNotComplete),
NotInitialized(NotInitialized),
NotIp(NotIp),
NotIpPort(NotIpPort),
PublicKeyAlreadyExists(PublicKeyAlreadyExists),
Unauthorized(Unauthorized),
AddressAlreadyHasValidator(AddressAlreadyHasValidator),
ValidatorAlreadyDeactivated(ValidatorAlreadyDeactivated),
ValidatorNotFound(ValidatorNotFound),
}Expand description
Container for all the IValidatorConfigV2 custom errors.
Variants
AlreadyInitialized(AlreadyInitialized)
IngressAlreadyExists(IngressAlreadyExists)
EmptyV1ValidatorSet(EmptyV1ValidatorSet)
InvalidMigrationIndex(InvalidMigrationIndex)
InvalidOwner(InvalidOwner)
InvalidPublicKey(InvalidPublicKey)
InvalidSignature(InvalidSignature)
InvalidSignatureFormat(InvalidSignatureFormat)
InvalidValidatorAddress(InvalidValidatorAddress)
MigrationNotComplete(MigrationNotComplete)
NotInitialized(NotInitialized)
NotIp(NotIp)
NotIpPort(NotIpPort)
PublicKeyAlreadyExists(PublicKeyAlreadyExists)
AddressAlreadyHasValidator(AddressAlreadyHasValidator)
ValidatorAlreadyDeactivated(ValidatorAlreadyDeactivated)
ValidatorNotFound(ValidatorNotFound)
Implementations
Sourceimpl IValidatorConfigV2Errors
impl IValidatorConfigV2Errors
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl IValidatorConfigV2Errors
impl IValidatorConfigV2Errors
Sourcepub fn already_initialized() -> Self
pub fn already_initialized() -> Self
Creates a AlreadyInitialized error.
error AlreadyInitialized()Sourcepub fn ingress_already_exists(ingress: String) -> Self
pub fn ingress_already_exists(ingress: String) -> Self
Creates a IngressAlreadyExists error.
error IngressAlreadyExists(string)Sourcepub fn empty_v_1_validator_set() -> Self
pub fn empty_v_1_validator_set() -> Self
Creates a EmptyV1ValidatorSet error.
error EmptyV1ValidatorSet()Sourcepub fn invalid_migration_index() -> Self
pub fn invalid_migration_index() -> Self
Creates a InvalidMigrationIndex error.
error InvalidMigrationIndex()Sourcepub fn invalid_owner() -> Self
pub fn invalid_owner() -> Self
Creates a InvalidOwner error.
error InvalidOwner()Sourcepub fn invalid_public_key() -> Self
pub fn invalid_public_key() -> Self
Creates a InvalidPublicKey error.
error InvalidPublicKey()Sourcepub fn invalid_signature() -> Self
pub fn invalid_signature() -> Self
Creates a InvalidSignature error.
error InvalidSignature()Sourcepub fn invalid_signature_format() -> Self
pub fn invalid_signature_format() -> Self
Creates a InvalidSignatureFormat error.
error InvalidSignatureFormat()Sourcepub fn invalid_validator_address() -> Self
pub fn invalid_validator_address() -> Self
Creates a InvalidValidatorAddress error.
error InvalidValidatorAddress()Sourcepub fn migration_not_complete() -> Self
pub fn migration_not_complete() -> Self
Creates a MigrationNotComplete error.
error MigrationNotComplete()Sourcepub fn not_initialized() -> Self
pub fn not_initialized() -> Self
Creates a NotInitialized error.
error NotInitialized()Sourcepub fn not_ip(input: String, backtrace: String) -> Self
pub fn not_ip(input: String, backtrace: String) -> Self
Creates a NotIp error.
error NotIp(string,string)Sourcepub fn not_ip_port(input: String, backtrace: String) -> Self
pub fn not_ip_port(input: String, backtrace: String) -> Self
Creates a NotIpPort error.
error NotIpPort(string,string)Sourcepub fn public_key_already_exists() -> Self
pub fn public_key_already_exists() -> Self
Creates a PublicKeyAlreadyExists error.
error PublicKeyAlreadyExists()Creates a Unauthorized error.
error Unauthorized()Sourcepub fn address_already_has_validator() -> Self
pub fn address_already_has_validator() -> Self
Creates a AddressAlreadyHasValidator error.
error AddressAlreadyHasValidator()Sourcepub fn validator_already_deactivated() -> Self
pub fn validator_already_deactivated() -> Self
Creates a ValidatorAlreadyDeactivated error.
error ValidatorAlreadyDeactivated()Sourcepub fn validator_not_found() -> Self
pub fn validator_not_found() -> Self
Creates a ValidatorNotFound error.
error ValidatorNotFound()Sourceimpl ValidatorConfigV2Error
impl ValidatorConfigV2Error
Sourcepub fn empty_v1_validator_set() -> Self
pub fn empty_v1_validator_set() -> Self
Backwards-compatible alias for the Alloy-generated empty_v_1_validator_set constructor.