pub enum IValidatorConfigV2Events {
ValidatorAdded(ValidatorAdded),
ValidatorDeactivated(ValidatorDeactivated),
ValidatorRotated(ValidatorRotated),
FeeRecipientUpdated(FeeRecipientUpdated),
IpAddressesUpdated(IpAddressesUpdated),
ValidatorOwnershipTransferred(ValidatorOwnershipTransferred),
OwnershipTransferred(OwnershipTransferred),
ValidatorMigrated(ValidatorMigrated),
NetworkIdentityRotationEpochSet(NetworkIdentityRotationEpochSet),
Initialized(Initialized),
SkippedValidatorMigration(SkippedValidatorMigration),
}Expand description
Container for all the IValidatorConfigV2 events.
Variants
ValidatorAdded(ValidatorAdded)
ValidatorDeactivated(ValidatorDeactivated)
ValidatorRotated(ValidatorRotated)
FeeRecipientUpdated(FeeRecipientUpdated)
IpAddressesUpdated(IpAddressesUpdated)
ValidatorOwnershipTransferred(ValidatorOwnershipTransferred)
OwnershipTransferred(OwnershipTransferred)
ValidatorMigrated(ValidatorMigrated)
NetworkIdentityRotationEpochSet(NetworkIdentityRotationEpochSet)
Initialized(Initialized)
SkippedValidatorMigration(SkippedValidatorMigration)
Implementations
Sourceimpl IValidatorConfigV2Events
impl IValidatorConfigV2Events
Sourcepub const SELECTORS: &'static [[u8; 32]]
pub const SELECTORS: &'static [[u8; 32]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl IValidatorConfigV2Events
impl IValidatorConfigV2Events
Sourcepub fn validator_added(
index: u64,
validator_address: Address,
public_key: FixedBytes<32>,
ingress: String,
egress: String,
fee_recipient: Address,
) -> Self
pub fn validator_added( index: u64, validator_address: Address, public_key: FixedBytes<32>, ingress: String, egress: String, fee_recipient: Address, ) -> Self
Creates a ValidatorAdded event.
event ValidatorAdded(uint64,address,bytes32,string,string,address)Sourcepub fn validator_deactivated(index: u64, validator_address: Address) -> Self
pub fn validator_deactivated(index: u64, validator_address: Address) -> Self
Creates a ValidatorDeactivated event.
event ValidatorDeactivated(uint64,address)Sourcepub fn validator_rotated(
index: u64,
deactivated_index: u64,
validator_address: Address,
old_public_key: FixedBytes<32>,
new_public_key: FixedBytes<32>,
ingress: String,
egress: String,
caller: Address,
) -> Self
pub fn validator_rotated( index: u64, deactivated_index: u64, validator_address: Address, old_public_key: FixedBytes<32>, new_public_key: FixedBytes<32>, ingress: String, egress: String, caller: Address, ) -> Self
Creates a ValidatorRotated event.
event ValidatorRotated(uint64,uint64,address,bytes32,bytes32,string,string,address)Sourcepub fn fee_recipient_updated(
index: u64,
fee_recipient: Address,
caller: Address,
) -> Self
pub fn fee_recipient_updated( index: u64, fee_recipient: Address, caller: Address, ) -> Self
Creates a FeeRecipientUpdated event.
event FeeRecipientUpdated(uint64,address,address)Sourcepub fn ip_addresses_updated(
index: u64,
ingress: String,
egress: String,
caller: Address,
) -> Self
pub fn ip_addresses_updated( index: u64, ingress: String, egress: String, caller: Address, ) -> Self
Creates a IpAddressesUpdated event.
event IpAddressesUpdated(uint64,string,string,address)Sourcepub fn validator_ownership_transferred(
index: u64,
old_address: Address,
new_address: Address,
caller: Address,
) -> Self
pub fn validator_ownership_transferred( index: u64, old_address: Address, new_address: Address, caller: Address, ) -> Self
Creates a ValidatorOwnershipTransferred event.
event ValidatorOwnershipTransferred(uint64,address,address,address)Sourcepub fn ownership_transferred(old_owner: Address, new_owner: Address) -> Self
pub fn ownership_transferred(old_owner: Address, new_owner: Address) -> Self
Creates a OwnershipTransferred event.
event OwnershipTransferred(address,address)Sourcepub fn validator_migrated(
index: u64,
validator_address: Address,
public_key: FixedBytes<32>,
) -> Self
pub fn validator_migrated( index: u64, validator_address: Address, public_key: FixedBytes<32>, ) -> Self
Creates a ValidatorMigrated event.
event ValidatorMigrated(uint64,address,bytes32)Sourcepub fn network_identity_rotation_epoch_set(
previous_epoch: u64,
next_epoch: u64,
) -> Self
pub fn network_identity_rotation_epoch_set( previous_epoch: u64, next_epoch: u64, ) -> Self
Creates a NetworkIdentityRotationEpochSet event.
event NetworkIdentityRotationEpochSet(uint64,uint64)Sourcepub fn initialized(height: u64) -> Self
pub fn initialized(height: u64) -> Self
Creates a Initialized event.
event Initialized(uint64)Sourcepub fn skipped_validator_migration(
index: u64,
validator_address: Address,
public_key: FixedBytes<32>,
) -> Self
pub fn skipped_validator_migration( index: u64, validator_address: Address, public_key: FixedBytes<32>, ) -> Self
Creates a SkippedValidatorMigration event.
event SkippedValidatorMigration(uint64,address,bytes32)Trait Implementations
Sourceimpl Clone for IValidatorConfigV2Events
impl Clone for IValidatorConfigV2Events
Sourcefn clone(&self) -> IValidatorConfigV2Events
fn clone(&self) -> IValidatorConfigV2Events
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for IValidatorConfigV2Events
impl Debug for IValidatorConfigV2Events
Sourceimpl<'de> Deserialize<'de> for IValidatorConfigV2Events
impl<'de> Deserialize<'de> for IValidatorConfigV2Events
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
impl Eq for IValidatorConfigV2Events
Sourceimpl IntoLogData for IValidatorConfigV2Events
impl IntoLogData for IValidatorConfigV2Events
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
LogData] object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
LogData] object.Sourceimpl PartialEq for IValidatorConfigV2Events
impl PartialEq for IValidatorConfigV2Events
Sourcefn eq(&self, other: &IValidatorConfigV2Events) -> bool
fn eq(&self, other: &IValidatorConfigV2Events) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for IValidatorConfigV2Events
impl Serialize for IValidatorConfigV2Events
Sourceimpl SolEventInterface for IValidatorConfigV2Events
impl SolEventInterface for IValidatorConfigV2Events
Sourcefn decode_raw_log(topics: &[Word], data: &[u8]) -> Result<Self>
fn decode_raw_log(topics: &[Word], data: &[u8]) -> Result<Self>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
impl StructuralPartialEq for IValidatorConfigV2Events