IValidatorConfigV2Instance

Struct IValidatorConfigV2Instance 

pub struct IValidatorConfigV2Instance<P, N = Ethereum> {
    address: Address,
    provider: P,
    _network: PhantomData<N>,
}
A IValidatorConfigV2 instance.

Contains type-safe methods for interacting with an on-chain instance of the IValidatorConfigV2 contract located at a given address, using a given provider P.

If the contract bytecode is available (see the sol! documentation on how to provide it), the deploy and deploy_builder methods can be used to deploy a new instance of the contract.

See the module-level documentation for all the available methods.

Fields

address: Addressprovider: P_network: PhantomData<N>

Implementations

Source

impl<P: Provider<N>, N: Network> IValidatorConfigV2Instance<P, N>

Instantiation and getters/setters.

pub const fn new(address: Address, __provider: P) -> Self

Creates a new wrapper around an on-chain IValidatorConfigV2 contract instance.

See the wrapper’s documentation for more details.

pub const fn address(&self) -> &Address

Returns a reference to the address.

pub fn set_address(&mut self, address: Address)

Sets the address.

pub fn at(self, address: Address) -> Self

Sets the address and returns self.

pub const fn provider(&self) -> &P

Returns a reference to the provider.

Source

impl<P: Clone, N> IValidatorConfigV2Instance<&P, N>

pub fn with_cloned_provider(self) -> IValidatorConfigV2Instance<P, N>

Clones the provider and returns a new instance with the cloned provider.

Source

impl<P: Provider<N>, N: Network> IValidatorConfigV2Instance<P, N>

Function calls.

pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>

Creates a new call builder using this contract instance’s provider and address.

Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.

pub fn getActiveValidators( &self, ) -> SolCallBuilder<&P, getActiveValidatorsCall, N>

Creates a new call builder for the [getActiveValidators] function.

pub fn getInitializedAtHeight( &self, ) -> SolCallBuilder<&P, getInitializedAtHeightCall, N>

Creates a new call builder for the [getInitializedAtHeight] function.

pub fn owner(&self) -> SolCallBuilder<&P, ownerCall, N>

Creates a new call builder for the [owner] function.

pub fn validatorCount(&self) -> SolCallBuilder<&P, validatorCountCall, N>

Creates a new call builder for the [validatorCount] function.

pub fn validatorByIndex( &self, index: u64, ) -> SolCallBuilder<&P, validatorByIndexCall, N>

Creates a new call builder for the [validatorByIndex] function.

pub fn validatorByAddress( &self, validatorAddress: Address, ) -> SolCallBuilder<&P, validatorByAddressCall, N>

Creates a new call builder for the [validatorByAddress] function.

pub fn validatorByPublicKey( &self, publicKey: FixedBytes<32>, ) -> SolCallBuilder<&P, validatorByPublicKeyCall, N>

Creates a new call builder for the [validatorByPublicKey] function.

pub fn getNextNetworkIdentityRotationEpoch( &self, ) -> SolCallBuilder<&P, getNextNetworkIdentityRotationEpochCall, N>

Creates a new call builder for the [getNextNetworkIdentityRotationEpoch] function.

pub fn isInitialized(&self) -> SolCallBuilder<&P, isInitializedCall, N>

Creates a new call builder for the [isInitialized] function.

pub fn addValidator( &self, validatorAddress: Address, publicKey: FixedBytes<32>, ingress: String, egress: String, feeRecipient: Address, signature: Bytes, ) -> SolCallBuilder<&P, addValidatorCall, N>

Creates a new call builder for the [addValidator] function.

pub fn deactivateValidator( &self, idx: u64, ) -> SolCallBuilder<&P, deactivateValidatorCall, N>

Creates a new call builder for the [deactivateValidator] function.

pub fn rotateValidator( &self, idx: u64, publicKey: FixedBytes<32>, ingress: String, egress: String, signature: Bytes, ) -> SolCallBuilder<&P, rotateValidatorCall, N>

Creates a new call builder for the [rotateValidator] function.

pub fn setFeeRecipient( &self, idx: u64, feeRecipient: Address, ) -> SolCallBuilder<&P, setFeeRecipientCall, N>

Creates a new call builder for the [setFeeRecipient] function.

pub fn setIpAddresses( &self, idx: u64, ingress: String, egress: String, ) -> SolCallBuilder<&P, setIpAddressesCall, N>

Creates a new call builder for the [setIpAddresses] function.

pub fn transferValidatorOwnership( &self, idx: u64, newAddress: Address, ) -> SolCallBuilder<&P, transferValidatorOwnershipCall, N>

Creates a new call builder for the [transferValidatorOwnership] function.

pub fn transferOwnership( &self, newOwner: Address, ) -> SolCallBuilder<&P, transferOwnershipCall, N>

Creates a new call builder for the [transferOwnership] function.

pub fn setNetworkIdentityRotationEpoch( &self, epoch: u64, ) -> SolCallBuilder<&P, setNetworkIdentityRotationEpochCall, N>

Creates a new call builder for the [setNetworkIdentityRotationEpoch] function.

pub fn migrateValidator( &self, idx: u64, ) -> SolCallBuilder<&P, migrateValidatorCall, N>

Creates a new call builder for the [migrateValidator] function.

pub fn initializeIfMigrated( &self, ) -> SolCallBuilder<&P, initializeIfMigratedCall, N>

Creates a new call builder for the [initializeIfMigrated] function.

Source

impl<P: Provider<N>, N: Network> IValidatorConfigV2Instance<P, N>

Event filters.

pub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>

Creates a new event filter using this contract instance’s provider and address.

Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.

pub fn ValidatorAdded_filter(&self) -> Event<&P, ValidatorAdded, N>

Creates a new event filter for the ValidatorAdded event.

pub fn ValidatorDeactivated_filter(&self) -> Event<&P, ValidatorDeactivated, N>

Creates a new event filter for the ValidatorDeactivated event.

pub fn ValidatorRotated_filter(&self) -> Event<&P, ValidatorRotated, N>

Creates a new event filter for the ValidatorRotated event.

pub fn FeeRecipientUpdated_filter(&self) -> Event<&P, FeeRecipientUpdated, N>

Creates a new event filter for the FeeRecipientUpdated event.

pub fn IpAddressesUpdated_filter(&self) -> Event<&P, IpAddressesUpdated, N>

Creates a new event filter for the IpAddressesUpdated event.

pub fn ValidatorOwnershipTransferred_filter( &self, ) -> Event<&P, ValidatorOwnershipTransferred, N>

Creates a new event filter for the ValidatorOwnershipTransferred event.

pub fn OwnershipTransferred_filter(&self) -> Event<&P, OwnershipTransferred, N>

Creates a new event filter for the OwnershipTransferred event.

pub fn ValidatorMigrated_filter(&self) -> Event<&P, ValidatorMigrated, N>

Creates a new event filter for the ValidatorMigrated event.

pub fn NetworkIdentityRotationEpochSet_filter( &self, ) -> Event<&P, NetworkIdentityRotationEpochSet, N>

Creates a new event filter for the NetworkIdentityRotationEpochSet event.

pub fn Initialized_filter(&self) -> Event<&P, Initialized, N>

Creates a new event filter for the Initialized event.

pub fn SkippedValidatorMigration_filter( &self, ) -> Event<&P, SkippedValidatorMigration, N>

Creates a new event filter for the SkippedValidatorMigration event.