pub struct IngressAlreadyExists {
pub ingress: String,
}Expand description
Custom error with signature IngressAlreadyExists(string) and selector 0x8591b353.
error IngressAlreadyExists(string ingress);Fields
ingress: StringTrait Implementations
Sourceimpl Clone for IngressAlreadyExists
impl Clone for IngressAlreadyExists
Sourcefn clone(&self) -> IngressAlreadyExists
fn clone(&self) -> IngressAlreadyExists
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IngressAlreadyExists
impl Debug for IngressAlreadyExists
Sourceimpl<'de> Deserialize<'de> for IngressAlreadyExists
impl<'de> Deserialize<'de> for IngressAlreadyExists
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonAbiExt for IngressAlreadyExists
impl JsonAbiExt for IngressAlreadyExists
Sourceimpl PartialEq for IngressAlreadyExists
impl PartialEq for IngressAlreadyExists
Sourceimpl Serialize for IngressAlreadyExists
impl Serialize for IngressAlreadyExists
Sourceimpl SolError for IngressAlreadyExists
impl SolError for IngressAlreadyExists
Sourcetype Parameters<'a> = (String,)
type Parameters<'a> = (String,)
The underlying tuple type which represents the error’s members. Read more
Sourcetype Token<'a> = <<IngressAlreadyExists as SolError>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<IngressAlreadyExists as SolError>::Parameters<'a> as SolType>::Token<'a>
The corresponding [
TokenSeq] type.Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> Self::Token<'_>
fn tokenize(&self) -> Self::Token<'_>
Convert to the token type used for EIP-712 encoding and decoding.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
ABI decode this error’s arguments from the given slice, without its
selector, with validation. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the error params when encoded in bytes, without the
selector.
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector.
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector, with validation. Read more
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the error to the given buffer without its selector.
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
ABI encode the error to the given buffer with its selector.
impl Eq for IngressAlreadyExists
impl StructuralPartialEq for IngressAlreadyExists