pub enum IValidatorConfigV2Errors {
Show 18 variants
AlreadyInitialized(AlreadyInitialized),
IngressAlreadyExists(IngressAlreadyExists),
EmptyV1ValidatorSet(EmptyV1ValidatorSet),
InvalidMigrationIndex(InvalidMigrationIndex),
InvalidOwner(InvalidOwner),
InvalidPublicKey(InvalidPublicKey),
InvalidSignature(InvalidSignature),
InvalidSignatureFormat(InvalidSignatureFormat),
InvalidValidatorAddress(InvalidValidatorAddress),
MigrationNotComplete(MigrationNotComplete),
NotInitialized(NotInitialized),
NotIp(NotIp),
NotIpPort(NotIpPort),
PublicKeyAlreadyExists(PublicKeyAlreadyExists),
Unauthorized(Unauthorized),
AddressAlreadyHasValidator(AddressAlreadyHasValidator),
ValidatorAlreadyDeactivated(ValidatorAlreadyDeactivated),
ValidatorNotFound(ValidatorNotFound),
}Expand description
Container for all the IValidatorConfigV2 custom errors.
Variants
AlreadyInitialized(AlreadyInitialized)
IngressAlreadyExists(IngressAlreadyExists)
EmptyV1ValidatorSet(EmptyV1ValidatorSet)
InvalidMigrationIndex(InvalidMigrationIndex)
InvalidOwner(InvalidOwner)
InvalidPublicKey(InvalidPublicKey)
InvalidSignature(InvalidSignature)
InvalidSignatureFormat(InvalidSignatureFormat)
InvalidValidatorAddress(InvalidValidatorAddress)
MigrationNotComplete(MigrationNotComplete)
NotInitialized(NotInitialized)
NotIp(NotIp)
NotIpPort(NotIpPort)
PublicKeyAlreadyExists(PublicKeyAlreadyExists)
AddressAlreadyHasValidator(AddressAlreadyHasValidator)
ValidatorAlreadyDeactivated(ValidatorAlreadyDeactivated)
ValidatorNotFound(ValidatorNotFound)
Implementations
Sourceimpl IValidatorConfigV2Errors
impl IValidatorConfigV2Errors
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl ValidatorConfigV2Error
impl ValidatorConfigV2Error
pub const fn address_already_has_validator() -> Self
pub const fn public_key_already_exists() -> Self
pub const fn validator_not_found() -> Self
pub const fn validator_already_deactivated() -> Self
pub const fn invalid_public_key() -> Self
pub const fn invalid_signature() -> Self
pub const fn invalid_signature_format() -> Self
pub const fn invalid_validator_address() -> Self
pub const fn not_initialized() -> Self
pub const fn already_initialized() -> Self
pub const fn migration_not_complete() -> Self
pub const fn empty_v1_validator_set() -> Self
pub const fn invalid_migration_index() -> Self
pub const fn invalid_owner() -> Self
pub fn not_ip(input: String, backtrace: String) -> Self
pub fn not_ip_port(input: String, backtrace: String) -> Self
pub fn ingress_already_exists(ingress: String) -> Self